<?php

namespace Config;

// Create a new instance of our RouteCollection class.
$routes = Services::routes();

// Load the system's routing file first, so that the app and ENVIRONMENT
// can override as needed.
if (file_exists(SYSTEMPATH . 'Config/Routes.php')) {
    require SYSTEMPATH . 'Config/Routes.php';
}

/*
 * --------------------------------------------------------------------
 * Router Setup
 * --------------------------------------------------------------------
 */
$routes->setDefaultNamespace('App\Controllers');
// $routes->setDefaultController('Home');
$routes->setDefaultController('login');
$routes->setDefaultMethod('index');
$routes->setTranslateURIDashes(true);
$routes->set404Override();
$routes->setAutoRoute(true);

/*
 * --------------------------------------------------------------------
 * Route Definitions
 * --------------------------------------------------------------------
 */

// We get a performance increase by specifying the default
// route since we don't have to scan directories.
// $routes->get('/', 'Home::index');
$routes->get('/app/v1/api/generate_document', 'Api::generate_document');

$routes->group('/', ["namespace" => "App\Controllers\Seguridad"], function ($routes) {
    $routes->get('', 'Login::index');
    $routes->post('auth', 'Login::auth');
    $routes->get('logout', 'Login::logout');
    $routes->get('forgot-password', 'Login::forgot-password');
    $routes->get('recovery-password', 'Login::recovery-password');
    $routes->post('forgot', 'Login::forgot');
    $routes->post('recovery', 'Login::recovery');
    $routes->get('update-password/(:any)', 'Usuarios::update-password/$1');
    $routes->get('mail-forgot', 'Login::mails-forgot');
});

// $routes->get('/index', 'Pages::index', ['filter' => 'authGuard']);
$routes->get('/index', 'Pages::index');

// $routes->group('usuarios', ["namespace" => "App\Controllers\Seguridad", 'filter' => 'authGuard'], function ($routes) {
$routes->group('usuarios', ["namespace" => "App\Controllers\Seguridad"], function ($routes) {
    $routes->get('/', 'Usuarios::index');
    $routes->get('eliminar/(:any)', 'Usuarios::eliminar/$1');
    $routes->get('email/(:any)', 'Usuarios::email/$1');
    $routes->post('crear', 'Usuarios::crear');
    $routes->post('actualizar', 'Usuarios::actualizar');
    $routes->post('cvsimport', 'Usuarios::cvsimport');
    $routes->post('usuarios_cvs', 'Usuarios::usuarios_cvs');
});

$routes->group('documents', ["namespace" => "App\Controllers\Documents"], function ($routes) {
    $routes->get('/', 'Generate::index');
    $routes->get('generate_document', 'Generate::generate_document');
    $routes->get('eliminar/(:any)', 'Generate::delete_document/$1');
    $routes->get('editar_document', 'Generate::editar_document');
    $routes->get('download_document', 'Generate::download_document');
    $routes->get('filtrarRangoFecha', 'Generate::filtrarRangoFecha');
    $routes->get('document_xlsx', 'Generate::document_xlsx');
    // $routes->get('email/(:any)', 'Usuarios::email/$1');
    // $routes->post('crear', 'Usuarios::crear');
    // $routes->post('actualizar', 'Usuarios::actualizar');
    // $routes->post('cvsimport', 'Usuarios::cvsimport');
    // $routes->post('usuarios_cvs', 'Usuarios::usuarios_cvs');
});

$routes->group('tipos', ["namespace" => "App\Controllers\Catalogos"], function ($routes) {
    $routes->get('/', 'Tipos::index');
    $routes->get('eliminar/(:any)', 'Tipos::eliminar/$1');
    $routes->post('crear', 'Tipos::crear');
    $routes->post('actualizar', 'Tipos::actualizar');
    // $routes->post('cvsimport', 'Tipos::cvsimport');
    // $routes->post('usuarios_cvs', 'Usuarios::usuarios_cvs');
});

/*
 * --------------------------------------------------------------------
 * Additional Routing
 * --------------------------------------------------------------------
 *
 * There will often be times that you need additional routing and you
 * need it to be able to override any defaults in this file. Environment
 * based routes is one such time. require() additional route files here
 * to make that happen.
 *
 * You will have access to the $routes object within that file without
 * needing to reload it.
 */
if (file_exists(APPPATH . 'Config/' . ENVIRONMENT . '/Routes.php')) {
    require APPPATH . 'Config/' . ENVIRONMENT . '/Routes.php';
}
